@@ -27,7 +27,8 @@ class AssetQuery(BaseQuery):
         self.base_url = "{}/assets".format(self.http_instance.endpoint)
         if "environment" in self.http_instance.headers:
             env = self.http_instance.headers["environment"]
-            self.base_url = "{}?{}".format(self.base_url, "environment={}".format(env))
+            self.base_url = "{}?{}".format(
+                self.base_url, "environment={}".format(env))
 
     def environment(self, environment):
         r"""Provide the name of the environment if you wish to retrieve the assets published
@@ -82,6 +83,20 @@ class AssetQuery(BaseQuery):
         self.asset_query_params["include_dimension"] = "true"
         return self
 
+    def include_branch(self):
+        """Includes branch in the response
+        :return: Entry, so we can chain the call
+        ----------------------------
+        Example::
+
+            >>> import contentstack
+            >>> stack = contentstack.Stack('api_key', 'delivery_token', 'environment')
+            >>> result = stack.asset_query().include_branch().find()
+        ----------------------------
+        """
+        self.asset_query_params['include_branch'] = 'true'
+        return self
+
     def relative_url(self):
         r"""include the relative URLs of the assets in the response.
 
